@@ -3,6 +3,7 @@ import requests
 from requests.auth import HTTPBasicAuth
 from importlib import import_module
 
+from slai.config import get_api_base_url
 from slai.modules.parameters import from_config
 from slai.modules.runtime import detect_runtime, detect_credentials
 
@@ -22,15 +23,7 @@ def get_cli_client(client_id=None, client_secret=None):
 
 
 class SlaiCliClient:
-    STAGE = from_config(
-        key="STAGE",
-        default="staging",
-    )
-
-    BASE_URL = from_config(
-        key="BASE_URL",
-        default=f"https://api.slai.io/{STAGE}",
-    )
+    BASE_URL = get_api_base_url()
 
     def __init__(
         self,
