@@ -1,6 +1,7 @@
 import requests
 
 from slai.modules.parameters import from_config
+from slai.config import get_api_base_url
 from slai.modules.runtime import detect_runtime, detect_credentials
 from slai.clients.model import get_model_client
 
@@ -27,15 +28,7 @@ def get_inference_client(*, model_name, project_name, model_version_id):
 
 
 class ModelInferenceClient:
-    STAGE = from_config(
-        key="STAGE",
-        default="staging",
-    )
-
-    BASE_URL = from_config(
-        key="BASE_URL",
-        default=f"https://api.slai.io/{STAGE}",
-    )
+    BASE_URL = get_api_base_url()
 
     def __init__(self, *, model_name, project_name, model_version_id=None):
         self.runtime = detect_runtime()
