@@ -7,6 +7,7 @@ from slai.clients.model import get_model_client
 from slai.exceptions import UnsupportedModelFormat, UnableToConvertNotebook
 from slai.modules.model_saver import ModelSaver, ValidModelFrameworks
 from slai.modules.runtime import detect_runtime, ValidRuntimes
+from slai.modules import notebook_utils
 
 
 class ModelVersion:
@@ -20,7 +21,6 @@ class ModelVersion:
             model_name=self.model_name, project_name=self.project_name
         )
         self.project = self.model_client.project_client.get_project()
-
         self.model = self.model_client.get_model()
 
         if model_version_id is None:
@@ -79,22 +79,21 @@ class ModelVersion:
         sys.modules["__main__"] = trainer_module
 
     def _handle_local_notebook_trainer(self):
-        _subprocess = importlib.import_module("subprocess")
+        notebook_path = f"/workspace/models/{self.model_name}/{self.model_version_id}/notebook.ipynb"  # noqa
 
+        imports, trainer = notebook_utils.parse_notebook(notebook_path)
+        trainer_source = notebook_utils.generate_trainer_from_template(
+            model_name=self.model_name,
+            imports=imports,
+            trainer=trainer,
+            model_version_id=self.model_version_id,
+        )
         trainer_path = (
             f"/workspace/models/{self.model_name}/{self.model_version_id}/trainer.py"
         )
-        notebook_path = (
-            f"/workspace/models/{self.model_name}/{self.model_version_id}/ipynb.py"
-        )
 
-        return_code = _subprocess.call(
-            f"/workspace/env/{self.model_name}/bin/python -m jupyter nbconvert {notebook_path} --to=python",  # noqa
-            shell=True,
-        )
-
-        if return_code != 0:
-            raise UnableToConvertNotebook("could_not_convert_notebook")
+        with open(trainer_path, "w") as f_out:
+            f_out.write(trainer_source)
 
         spec = importlib.util.spec_from_file_location("trainer", trainer_path)
         trainer_module = importlib.util.module_from_spec(spec)
